==> wn_1.18.7-1.tar.gz: wn-1.18.7/wn/common.h <==
/*
    Wn: A Server for the HTTP
    File: wn/common.h
    Version 1.18.7
    
    Copyright (C) 1996  <by John Franks>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#ifndef TRUE
#define TRUE	(1)
#endif

#ifndef FALSE
#define FALSE	(0)
#endif

#define STANDARD_PORT	(80)

#define	MIDLEN		(2048)
#define	BIGLEN		(2*MIDLEN)
#define	CACHELINE_LEN	(4*MIDLEN)
#define	RANGELEN	(1024)
#define	SMALLLEN	(256)
#define	TINYLEN		(32)
#define INBUFFSIZE	(2048)
#define OUT_BUFFSIZE	(4096)

/* Bits in the Request attributes */
#define WN_DYNAMIC	(1)
#define WN_NONDYNAMIC	(2)
#define WN_POST_OK	(4)

#define	WN_SWRAPPED	(16)
#define	WN_FILTERED	(32)
#define	WN_NOSEARCH	(64)
#define	WN_PARSE	(128)
#define	WN_NOPARSE	(256)
#define	WN_CGI		(512)
#define WN_ISMAP	(1024)
#define WN_NOCACHE	(2048)
#define WN_UNBUFFERED	(4096)
#define WN_CACHEABLE	(8192)


/* Bits in the request attrib2 */
#define	WN_INCLUDE		(1)
#define	WN_WRAPPED		(2)
#define	WN_LIST_INCL		(4)
#define	WN_ISSEARCH		(8)

==> wn_2.0.5.orig.tar.gz: wn-2.0.5/wn/common.h <==
/*
    Wn: A Server for the HTTP
    File: wn/common.h
    Version 1.19.9
    
    Copyright (C) 1996  <by John Franks>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#ifndef TRUE
#define TRUE	(1)
#endif

#ifndef FALSE
#define FALSE	(0)
#endif

#define STANDARD_PORT	(80)

#define	MIDLEN		(2048)
#define	SMALLLEN	(MIDLEN/8)
#define	BIGLEN		(2*MIDLEN)
#define	CACHELINE_LEN	(4*MIDLEN)
#define	RANGELEN	(1024)
#define	TINYLEN		(32)
#define INBUFFSIZE	(2048)
#define OUT_BUFFSIZE	(4096)  /* MUST be less than FFFF hex */
				/* see end_chunking in send.c  */

/* Bits in the Request attributes */
#define WN_DYNAMIC	(1)
#define WN_NONDYNAMIC	(2)
#define WN_POST_ONLY	(4)
#define WN_PUT_OK	(8)
#define WN_NO_POST	(16)
#define	WN_FILTERED	(32)
#define	WN_NOSEARCH	(64)
#define	WN_PARSE	(128)
#define	WN_NOPARSE	(256)
#define	WN_CGI		(512)
#define WN_ISMAP	(1024)
#define WN_NOCACHE	(2048)
#define WN_UNBUFFERED	(4096)
#define WN_CACHEABLE	(8192)


/* Bits in the request attrib2 */
#define	WN_INCLUDE		(1)
#define	WN_WRAPPED		(2)
#define	WN_SWRAPPED		(4)
#define	WN_LIST_INCL		(8)
#define	WN_ISSEARCH		(16)
#define	WN_FILEMOD		(32)
#define	WN_ISACGIBIN		(64)
